{ *** AVR-CP/M
  *** A simple PRINT command for text files.
  *** Sends output via I2C UART.
  ***
  *** Usage:   PRINT filename
  *** Example: PRINT PRINT.PAS
  *** Martin Hepperle, September 2018
  *** }
Program Print;

Const
  I2C_UART_BASE = $50; { base port address of I2C register set }
  I2C_UART_THR  = $0;  { transmit hold register }
  I2C_UART_LSR  = $5;  { line status register }

Var
  Status:   Byte;
  i:        Integer;
  theFile:  Text;
  theLine:  String[255]; { maximum text file line length! }

{ ------------------------------------- }

Begin
}
  If ParamCount > 0 Then
  Begin
    Writeln ( 'Printing ', ParamStr(1) );

    Assign ( theFile, ParamStr(1) );
    Reset ( theFile );

    While not Eof( theFile ) Do
    Begin
      ReadLn ( theFile, theLine );

      { --- append CR/LF for output }
      theLine := theLine + Chr(13) + Chr(10);

      { --- output this line }
      For i:=1 To Length(theLine) Do
      Begin
       { --- check status to avoid THR overrun }
        Repeat
          Status := Port[I2C_UART_BASE + I2C_UART_LSR];
        Until Status and 32 = 32; { THR empty? }
        Port[I2C_UART_BASE + I2C_UART_THR] := Ord(theLine[i]);
      End;
    End;
  End
  Else
  Begin
    { --- test output }
    For Data := Ord('A') To Ord('z') Do
    Begin
     { --- check status to avoid THR overrun }
      Repeat
        Status := Port[I2C_UART_BASE + I2C_UART_LSR];
      Until Status and 32 = 32; { THR empty? }
      Port[I2C_UART_BASE + I2C_UART_THR] := Data;
    End;

    { --- check status to avoid THR overrun }
    Repeat
      Status := Port[I2C_UART_BASE + I2C_UART_LSR];
    Until Status and 32 = 32; { THR empty? }
    Port[I2C_UART_BASE + I2C_UART_THR] := 13;

    { --- check status to avoid THR overrun }
    Repeat
      Status := Port[I2C_UART_BASE + I2C_UART_LSR];
    Until Status and 32 = 32; { THR empty? }
    Port[I2C_UART_BASE + I2C_UART_THR] := 10;
  End;
End.

